==> haskell-blaze-html-0.9.0.1-14-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-blaze-html.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: blaze-html
version: 0.9.0.1
id: blaze-html-0.9.0.1-HT9MGj6kW7JIH7aaLXkr1R
key: blaze-html-0.9.0.1-HT9MGj6kW7JIH7aaLXkr1R
license: BSD3
maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
stability: Experimental
homepage: http://jaspervdj.be/blaze
synopsis: A blazingly fast HTML combinator library for Haskell
description:
    A blazingly fast HTML combinator library for the Haskell
    programming language. The Text.Blaze module is a good
    starting point, as well as this tutorial:
    <http://jaspervdj.be/blaze/tutorial.html>.
category: Text
author: Jasper Van der Jeugt, Simon Meier
exposed: True
indefinite: False
exposed-modules:
    Text.Blaze.Html Text.Blaze.Html.Renderer.Pretty
    Text.Blaze.Html.Renderer.String Text.Blaze.Html.Renderer.Text
    Text.Blaze.Html.Renderer.Utf8 Text.Blaze.Html4.FrameSet
    Text.Blaze.Html4.FrameSet.Attributes Text.Blaze.Html4.Strict
    Text.Blaze.Html4.Strict.Attributes Text.Blaze.Html4.Transitional
    Text.Blaze.Html4.Transitional.Attributes Text.Blaze.Html5
    Text.Blaze.Html5.Attributes Text.Blaze.XHtml1.FrameSet
    Text.Blaze.XHtml1.FrameSet.Attributes Text.Blaze.XHtml1.Strict
    Text.Blaze.XHtml1.Strict.Attributes Text.Blaze.XHtml1.Transitional
    Text.Blaze.XHtml1.Transitional.Attributes Text.Blaze.XHtml5
    Text.Blaze.XHtml5.Attributes
abi: 73d2b9544f01cd8acaf404bd9dc45c3e
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/blaze-html-0.9.0.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/blaze-html-0.9.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/blaze-html-0.9.0.1
hs-libraries: HSblaze-html-0.9.0.1-HT9MGj6kW7JIH7aaLXkr1R
depends:
    base-4.10.1.0 blaze-builder-0.4.1.0-76A6rNBvwvR8MTgrMARis4
    blaze-markup-0.8.2.0-CnWoybGhIGoVpPCZ0nkq3 bytestring-0.10.8.2
    text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             blaze-builder-0.4.1.0-76A6rNBvwvR8MTgrMARis4=df56dd2a069eaa62b68a7725fcf6fae4
             blaze-markup-0.8.2.0-CnWoybGhIGoVpPCZ0nkq3=88ae80c9035b7e1542563395a63147b4
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj=d51c5ac73448d7d6c9cbe4dedb95457e
haddock-interfaces: /usr/share/doc/haskell-blaze-html/html/blaze-html.haddock
haddock-html: /usr/share/doc/haskell-blaze-html/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-blaze-html-0.9.0.1-15-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-blaze-html.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: blaze-html
version: 0.9.0.1
id: blaze-html-0.9.0.1-HqpSz28u1FiCfAogiiZCfO
key: blaze-html-0.9.0.1-HqpSz28u1FiCfAogiiZCfO
license: BSD3
maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
stability: Experimental
homepage: http://jaspervdj.be/blaze
synopsis: A blazingly fast HTML combinator library for Haskell
description:
    A blazingly fast HTML combinator library for the Haskell
    programming language. The Text.Blaze module is a good
    starting point, as well as this tutorial:
    <http://jaspervdj.be/blaze/tutorial.html>.
category: Text
author: Jasper Van der Jeugt, Simon Meier
exposed: True
indefinite: False
exposed-modules:
    Text.Blaze.Html Text.Blaze.Html.Renderer.Pretty
    Text.Blaze.Html.Renderer.String Text.Blaze.Html.Renderer.Text
    Text.Blaze.Html.Renderer.Utf8 Text.Blaze.Html4.FrameSet
    Text.Blaze.Html4.FrameSet.Attributes Text.Blaze.Html4.Strict
    Text.Blaze.Html4.Strict.Attributes Text.Blaze.Html4.Transitional
    Text.Blaze.Html4.Transitional.Attributes Text.Blaze.Html5
    Text.Blaze.Html5.Attributes Text.Blaze.XHtml1.FrameSet
    Text.Blaze.XHtml1.FrameSet.Attributes Text.Blaze.XHtml1.Strict
    Text.Blaze.XHtml1.Strict.Attributes Text.Blaze.XHtml1.Transitional
    Text.Blaze.XHtml1.Transitional.Attributes Text.Blaze.XHtml5
    Text.Blaze.XHtml5.Attributes
abi: 5b9e50f475d80821e5ba250ac60c1064
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/blaze-html-0.9.0.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/blaze-html-0.9.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/blaze-html-0.9.0.1
hs-libraries: HSblaze-html-0.9.0.1-HqpSz28u1FiCfAogiiZCfO
depends:
    base-4.10.1.0 blaze-builder-0.4.1.0-76A6rNBvwvR8MTgrMARis4
    blaze-markup-0.8.2.1-Cc3m1hen7WY3VxZJEwMXDb bytestring-0.10.8.2
    text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             blaze-builder-0.4.1.0-76A6rNBvwvR8MTgrMARis4=df56dd2a069eaa62b68a7725fcf6fae4
             blaze-markup-0.8.2.1-Cc3m1hen7WY3VxZJEwMXDb=e08bcee0ef3e79aea016c4a61a6fce39
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj=d51c5ac73448d7d6c9cbe4dedb95457e
haddock-interfaces: /usr/share/doc/haskell-blaze-html/html/blaze-html.haddock
haddock-html: /usr/share/doc/haskell-blaze-html/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
